import 'dart:async';
import 'dart:convert';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_webview_plugin/flutter_webview_plugin.dart';
import 'package:shuftipro_flutter_sdk/ApiMethods.dart';
import 'package:shuftipro_flutter_sdk/ShuftiProVerifications.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:app_settings/app_settings.dart';
import 'package:permission_handler/permission_handler.dart';


bool isShuftiPro = false, asyncSDK = false, isCheck = false, isPayloadSet = false;
var authObjectSDK;
var userHome;
Map<String, Object> createdPayloadTemp={}, createdPayloadSDK= {}, requestedPayload={};
List<String> verificationTypeList = [];
List<int> indexTempList = [];

String verificatonCancel =
    "\"verification_process_closed\", \"1\",\"message\", \"User cancel the verification process\"";

class ShuftiPro extends StatefulWidget {
  final CalbackFunction callback;

  // constructor get and set values
  ShuftiPro(
      {
        var authObject,
        required Map<String, Object> createdPayload,
        required bool async,
        var homeClass,
        required this.callback}) {
    authObjectSDK = authObject;
    createdPayloadSDK = createdPayload;
    asyncSDK = async;
    userHome = homeClass;
  }

  @override
  ShuftiProState createState() => new ShuftiProState();
}

// this class runs several times during widget lifecycle
class ShuftiProState extends State<ShuftiPro> {
  // get nationality of the country provided
  String getArrayInfo(List theMap, String searchText) {
    for (var val in theMap) {
      if (val['iso_code'] == searchText) return (val['nationality']);
    }
    return 'not found';
  }

  // check if the auth parameters are given or not
  checksToProceed() {
    if ((authObjectSDK["access_token"] == null ||
        !authObjectSDK.containsKey("access_token") ||
        authObjectSDK["access_token"] == "")) {
      if (authObjectSDK["client_id"] == null ||
          !authObjectSDK.containsKey("client_id") ||
          authObjectSDK["client_id"] == "") {
        widget.callback(
            "ClientId cannot be empty. Please, provide your client id.");
        Navigator.pushAndRemoveUntil(
            context,
            MaterialPageRoute(builder: (context) => userHome),
                (route) => false);
      } else if (authObjectSDK["secret_key"] == null ||
          !authObjectSDK.containsKey("secret_key") ||
          authObjectSDK["secret_key"] == "") {
        widget.callback(
            "Secret key cannot be empty. Please, provide your secret key.");
        Navigator.pushAndRemoveUntil(
            context,
            MaterialPageRoute(builder: (context) => userHome),
                (route) => false);
      }
    }
  }

  // reads json file to check the country code
  Future<void> readJson() async {
    final String response = await DefaultAssetBundle.of(context)
        .loadString('assets/sdk/countries.json');
    data = await json.decode(response);

    if (createdPayloadSDK.containsKey('country') &&
        createdPayloadSDK['country'] != null) {
      nationality = getArrayInfo(data, createdPayloadSDK['country'].toString());
    } else {
      nationality = "";
    }
  }

  // consent screen checkbox
  void ConsentChk(bool? newVal) => setState(() {
    isCheck = newVal!;
    if (isCheck) {
    } else if (!isCheck) {}
  });

  bool isWebViewOpened = false;

  // initialise the state and set screen orientation.
  @override
  void initState() {
    super.initState();

    WidgetsBinding.instance?.addPostFrameCallback((_) => checksToProceed());

    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitUp,
      DeviceOrientation.portraitDown,
    ]);
  }

  // build the widget
  @override
  Widget build(BuildContext context) {
    readJson();
    // backpress confirmation dialog
    Future<bool> _onBackPressed() {
      return showDialog(
        context: context,
        barrierDismissible: false,
        builder: (context) => new AlertDialog(
          title: new Text(
            'Confirm Cancellation',
            style: new TextStyle(fontFamily: 'OpenSans'),
          ),
          content: new Text(
            'Are you sure you want to cancel the verification process?',
            style: new TextStyle(fontFamily: 'OpenSans'),
          ),
          actions: <Widget>[
            Padding(
              padding: const EdgeInsets.all(8.0),
              child: new GestureDetector(
                onTap: () => Navigator.of(context).pop(false),
                child: Text(
                  "Not Now",
                  style: new TextStyle(
                      fontSize: 13.w,
                      color: Color(0xff2b6ad8),
                      fontFamily: 'OpenSans'),
                ),
              ),
            ),
            SizedBox(height: 16),
            Padding(
              padding: const EdgeInsets.all(8.0),
              child: new GestureDetector(
                onTap: () => {
                  isCheck = false,
                  indexTempList = [],
                  verificationTypeList = [],
                  isPayloadSet = false,
                  supportedTypes_list = [],
                  Navigator.pushAndRemoveUntil(
                      context,
                      MaterialPageRoute(builder: (context) => userHome),
                          (route) => false),
                  widget.callback(verificatonCancel),
                },
                child: Text(
                  "Confirm",
                  style: new TextStyle(
                      fontSize: 13.w,
                      color: Color(0xff2b6ad8),
                      fontFamily: 'OpenSans'),
                ),
              ),
            ),
          ],
        ),
      ).then((value) => value ?? false);
    }

    // show dialog if internet connectivity is lost
    Future<dynamic> internetDialog() {
      return showDialog(
        context: context,
        barrierDismissible: false,
        builder: (context) => new AlertDialog(
          title: new Text(
            'Internet Disconnect.',
            style: new TextStyle(fontFamily: 'OpenSans'),
          ),
          content: new Text(
            'Internet is not availabe. Connect internet to proceed.',
            style: new TextStyle(fontFamily: 'OpenSans'),
          ),
          actions: <Widget>[
            Padding(
              padding: const EdgeInsets.all(8.0),
              child: new GestureDetector(
                onTap: () => Navigator.of(context).pop(false),
                child: Text(
                  "Cancel",
                  style: new TextStyle(fontFamily: 'OpenSans'),
                ),
              ),
            ),
            SizedBox(height: 16),
            Padding(
              padding: const EdgeInsets.all(8.0),
              child: new GestureDetector(
                onTap: () {
                  AppSettings.openWIFISettings();
                  Navigator.pushAndRemoveUntil(
                      context,
                      MaterialPageRoute(builder: (context) => userHome),
                          (route) => false);
                },
                child: Text(
                  "OK",
                  style: new TextStyle(fontFamily: 'OpenSans'),
                ),
              ),
            ),
          ],
        ),
      ) .then((value) => value ?? false);
    }

    if (!isPayloadSet) {
      isPayloadSet = true;
      requestedPayload = shufti_pro();
    }

    //Open webview in offiste verification
    if ((requestedPayload.containsKey("open_webView") &&
        requestedPayload["open_webView"] == true) ||
        (!requestedPayload.containsKey("face") &&
            !requestedPayload.containsKey("document") &&
            !requestedPayload.containsKey("document_two") &&
            !requestedPayload.containsKey("address") &&
            !requestedPayload.containsKey("consent") &&
            (requestedPayload.containsKey("background_checks") ||
                requestedPayload.containsKey("phone")))) {
      check().then((intenet) {
        if (intenet != null && intenet) {
          ApiMethods().apiRequest().then((value) async {
            if (!isWebViewOpened) {
              isWebViewOpened = true;
              isPayloadSet = false;
              if (value.contains("verification_url")) {
                final onsite_response = json.decode(value);

                if (await Permission.camera.request().isGranted &&
                    await Permission.microphone.request().isGranted) {
                  Navigator.push(
                    context,
                    MaterialPageRoute(
                        builder: (context) => Onsite(
                          onsite_response['verification_url'].toString(),
                          callback: (res) {
                            widget.callback(res);
                            print("\n\ncalling preview: " + res.toString());
                          }, title: '',
                        )),
                  );
                } else {
                  // You can request multiple permissions at once.
                  Map<Permission, PermissionStatus> statuses = await [
                    Permission.camera,
                    Permission.microphone,
                  ].request();
                }
              } else {
                widget.callback(value);
                Navigator.pushAndRemoveUntil(
                    context,
                    MaterialPageRoute(builder: (context) => userHome),
                        (route) => false);
              }
            }
          });
        } else {
          internetDialog();
        }
      });

      // ApiMethods().statusApiRequest().then((value) async {
      //   print("\n\n\n hehehe: " + value.toString() + "\n\n");
      // });
      return Scaffold(
        backgroundColor: Colors.white,
        body: Center(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Image.asset(
                  "assets/sdk/Preload_Animation.gif",
                  height: 100.h,
                  width: 0.4.sw,
                ),
                Padding(
                  padding: EdgeInsets.only(
                    top: 25.w,
                    left: 25.w,
                    bottom: 5.w,
                    right: 25.w,
                  ),
                  child: Container(
                    child: Center(
                      child: Text(
                        "Opening WebView..",
                        style: TextStyle(fontFamily: 'OpenSans', fontSize: 17.sp),
                      ),
                    ),
                  ),
                ),
                Padding(
                  padding: EdgeInsets.only(
                    top: 1.w,
                    left: 25.w,
                    bottom: 5.w,
                    right: 25.w,
                  ),
                  child: Container(
                    child: Center(
                      child: Text(
                        "Please Wait...",
                        style: TextStyle(
                            fontFamily: 'OpenSans',
                            fontSize: 18.sp,
                            fontWeight: FontWeight.bold),
                      ),
                    ),
                  ),
                ),
              ],
            )),
      );
    }
    else {
      // Offsite verification
      // show consent screen id show consent parameter is 1
      if (requestedPayload["show_consent"] == 1) {
        return ScreenUtilInit(
            builder: () => WillPopScope(
              onWillPop: _onBackPressed,
              child: Scaffold(
                backgroundColor: Colors.white,
                body: Center(
                  child: Column(
                    children: <Widget>[
                      Padding(
                        padding: EdgeInsets.only(
                          top: 30.w,
                        ),
                        child: Container(
                          height: 50.h,
                          width: 1.sw,
                          alignment: Alignment.center,
                          child: new Text(
                            "Declaration of Consent",
                            style: new TextStyle(
                              fontSize: 18.sp,
                              fontWeight: FontWeight.bold,
                              color: Colors.black,
                              fontFamily: 'OpenSans',
                            ),
                          ),
                        ),
                      ),
                      Padding(
                        padding: EdgeInsets.only(
                          top: 10.w,
                          left: 20.w,
                          bottom: 5.w,
                          right: 20.w,
                        ),
                        child: Container(
                          alignment: Alignment.topLeft,
                          child: new Text(
                            "Help us verify your\nidentity",
                            style: new TextStyle(
                              fontSize: 24.sp,
                              fontWeight: FontWeight.bold,
                              color: Colors.black,
                              fontFamily: 'OpenSans',
                            ),
                          ),
                        ),
                      ),
                      Padding(
                        padding: EdgeInsets.only(
                          top: 5.w,
                          left: 18.w,
                          bottom: 5.w,
                          right: 18.w,
                        ),
                        child: Container(
                          alignment: Alignment.topLeft,
                          child: new Text(
                            "Identity Verification Consent",
                            style: new TextStyle(
                              fontSize: 17.sp,
                              fontWeight: FontWeight.normal,
                              color: Colors.black,
                              fontFamily: 'OpenSans',
                            ),
                          ),
                        ),
                      ),
                      SizedBox(
                        height: 220.h,
                        width: 1.sw,
                        child: Expanded(
                          child: Padding(
                            padding: EdgeInsets.only(
                              top: 7.w,
                              left: 18.w,
                              bottom: 5.w,
                              right: 18.w,
                            ),
                            child: SingleChildScrollView(
                              scrollDirection: Axis.vertical,
                              child: Container(
                                alignment: Alignment.topLeft,
                                child: new Text(
                                  "I declare that I am at least 16 years of age; I agree to the collection, processing or storage"
                                      " of my personal information by Shufti Pro for the purpose(s) of identity verification; that the information"
                                      " I provide is true and accurate to the best of my knowledge; and I shall be fully responsible in case I provide"
                                      " wrong information or any of the documents I use are fake, forged, counterfeit, etc.",
                                  style: new TextStyle(
                                    fontSize: 14.5.sp,
                                    fontWeight: FontWeight.normal,
                                    color: Colors.black,
                                    fontFamily: 'OpenSans',
                                  ),
                                ),
                              ),
                            ),
                          ),
                        ),
                      ),
                      Container(
                          child: Row(
                            children: <Widget>[
                              Container(
                                child: Checkbox(
                                  value: isCheck,
                                  onChanged: ConsentChk,
                                ),
                              ),
                              Padding(
                                padding: EdgeInsets.only(
                                  bottom: 5.w,
                                ),
                                child: Container(
                                  width: 0.85.sw,
                                  alignment: Alignment.topLeft,
                                  child: RichText(
                                    text: new TextSpan(
                                      children: [
                                        new TextSpan(
                                          text:
                                          "I agree to the above statement, and I have read the ",
                                          style: new TextStyle(
                                            fontSize: 14.5.sp,
                                            fontWeight: FontWeight.normal,
                                            color: Colors.black,
                                            fontFamily: 'OpenSans',
                                          ),
                                        ),
                                        new TextSpan(
                                          text: 'Privacy Policy',
                                          style: new TextStyle(
                                            fontSize: 14.5.sp,
                                            fontWeight: FontWeight.normal,
                                            decoration:
                                            TextDecoration.underline,
                                            color: Colors.blue,
                                            fontFamily: 'OpenSans',
                                          ),
                                          recognizer: new TapGestureRecognizer()
                                            ..onTap = () {
                                              launch(
                                                  'https://shuftipro.com/privacy-policy');
                                            },
                                        ),
                                        new TextSpan(
                                          text:
                                          " of Shufti Pro.",
                                          style: new TextStyle(
                                            fontSize: 14.5.sp,
                                            fontWeight: FontWeight.normal,
                                            color: Colors.black,
                                            fontFamily: 'OpenSans',
                                          ),
                                        ),
                                      ],
                                    ),
                                  ),
                                ),
                              ),
                            ],
                          )),
                      Spacer(),
                      Padding(
                        padding: EdgeInsets.only(
                          top: 7.w,
                          left: 10.w,
                          bottom: 5.w,
                          right: 10.w,
                        ),
                        child: Container(
                          height: 45.h,
                          width: 1.sw,
                          child: RaisedButton(
                            onPressed: isCheck
                                ? () => Navigator.push(
                              context,
                              MaterialPageRoute(
                                  builder:
                                      (context) => ShowInstructions(
                                    callback: (res) {
                                      widget.callback(res);
                                      print("\n\ncalling preview: " +
                                          res.toString());
                                    },
                                  )),
                            )
                                : null,
                            textColor: Colors.white,
                            color: Color(0xff2b6ad8),
                            child: new Container(
                              margin: const EdgeInsets.fromLTRB(5, 0, 0, 0),
                              child: new Text(
                                "Yes, Continue",
                                textAlign: TextAlign.center,
                                style: new TextStyle(
                                  fontSize: 17.sp,
                                  fontWeight: FontWeight.bold,
                                  color: Colors.white,
                                  fontFamily: 'OpenSans',
                                ),
                              ),
                            ),
                          ),
                        ),
                      ),
                      Padding(
                        padding: EdgeInsets.only(
                          left: 10.w,
                          right: 10.w,
                        ),
                        child: Container(
                          height: 45.h,
                          width: 1.sw,
                          child: OutlinedButton(
                            onPressed: () {
                              _onBackPressed();
                            },
                            style: OutlinedButton.styleFrom(
                              shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(5)),
                            ),
                            child: new Container(
                              margin: const EdgeInsets.fromLTRB(5, 0, 0, 0),
                              child: new Text(
                                "No, Cancel",
                                textAlign: TextAlign.center,
                                style: new TextStyle(
                                  fontSize: 17.sp,
                                  fontWeight: FontWeight.bold,
                                  color: Colors.black,
                                  fontFamily: 'OpenSans',
                                ),
                              ),
                            ),
                          ),
                        ),
                      ),
                      Spacer(),
                      Container(
                          height: 13.h,
                          child:
                          Image.asset("assets/images/footerImage.png")),
                    ],
                  ),
                ),
              ),
            ));
      } else {
        // show instructions screen if show consent is 0
        WidgetsBinding.instance?.addPostFrameCallback((_) {
          Navigator.push(
            context,
            MaterialPageRoute(
                builder: (context) => ShowInstructions(
                  callback: (res) {
                    widget.callback(res);
                    print("\n\ncalling preview: " + res.toString());
                  },
                )),
          );
        });

        return Scaffold(
          backgroundColor: Colors.white,
          body: Center(
            child: Text(
              "Opening Web..",
              style: TextStyle(
                fontFamily: 'OpenSans',
              ),
            ),
          ),
        );
      }
    }
  }

  // creates and returns the request payload in hash map form
  Map<String, Object> shufti_pro() {
    createdPayloadSDK["redirect_url"] = "http://www.example.com";
    if (asyncSDK == null) {
      asyncSDK = false;
    }

    if (!createdPayloadSDK.containsKey("verification_mode") ||
        createdPayloadSDK.containsKey("verification_mode") == null) {
      createdPayloadSDK["verification_mode"] = "image_only";
    }
    if (!createdPayloadSDK.containsKey("show_consent")) {
      createdPayloadSDK["show_consent"] = 1;
    }
    if (!createdPayloadSDK.containsKey("show_results")) {
      createdPayloadSDK["show_results"] = 1;
    }
    if (!createdPayloadSDK.containsKey("show_privacy_policy")) {
      createdPayloadSDK["show_privacy_policy"] = 1;
    }
    if (createdPayloadSDK.containsKey("face")) {
      if (createdPayloadSDK['face'].toString() == "{}") {
        createdPayloadSDK['face'] = {"": ""};
      }

      verificationTypeList.add("face");
      indexTempList.add(createdPayloadSDK.toString().indexOf(' face:'));

      createdPayloadTemp = createdPayloadSDK["face"] as Map<String,Object>;
      createdPayloadTemp["proof"] = "";
      createdPayloadSDK["face"] = createdPayloadTemp;
    }
    if (createdPayloadSDK.containsKey("document")) {
      if (createdPayloadSDK['document'].toString() == "{}") {
        createdPayloadSDK['document'] = {
          "supported_types": [
            "passport",
            "id_card",
            "driving_license",
            "credit_or_debit_card",
          ],
          "name": {
            "first_name": "John",
            "last_name": "",
            "middle_name": "",
          },
          "dob": "",
          "document_number": "",
          "expiry_date": "",
          "issue_date": "",
          "fetch_enhanced_data": "",
          "gender": "",
          "backside_proof_required": "0",
        };
      } else {
        createdPayloadTemp = createdPayloadSDK["document"] as Map<String,Object>;
        createdPayloadTemp["proof"] = "";
        createdPayloadTemp["additional_proof"] = "";
        createdPayloadSDK["document"] = createdPayloadTemp;
      }
      verificationTypeList.add("document");
      indexTempList.add(createdPayloadSDK.toString().indexOf(' document:'));
    }
    if (createdPayloadSDK.containsKey("document_two")) {
      if (createdPayloadSDK['document_two'].toString() == "{}") {
        createdPayloadSDK['document_two'] = {
          "supported_types": [
            "passport",
            "id_card",
            "driving_license",
            "credit_or_debit_card"
          ],
          "name": {"first_name": "", "last_name": "", "middle_name": ""},
          "dob": "",
          "document_number": "",
          "expiry_date": "",
          "issue_date": "",
          "fetch_enhanced_data": "",
          "gender": "",
          "backside_proof_required": "0",
        };
      }

      verificationTypeList.add("document_two");
      indexTempList.add(createdPayloadSDK.toString().indexOf(' document_two:'));

      createdPayloadTemp = createdPayloadSDK["document_two"] as Map<String,Object>;
      createdPayloadTemp["proof"] = "";
      createdPayloadTemp["additional_proof"] = "";
      createdPayloadSDK["document_two"] = createdPayloadTemp;
    }
    if (createdPayloadSDK.containsKey("address")) {
      if (createdPayloadSDK['address'].toString() == "{}") {
        createdPayloadSDK['address'] = {
          "full_address": "",
          "name": {
            "first_name": "",
            "last_name": "",
            "middle_name": "",
            "fuzzy_match": "",
          },
          "supported_types": ["id_card", "utility_bill", "bank_statement"],
          "backside_proof_required": "0",
        };
      }

      verificationTypeList.add("address");
      indexTempList.add(createdPayloadSDK.toString().indexOf(' address:'));

      createdPayloadTemp = createdPayloadSDK["address"] as Map<String,Object>;
      createdPayloadTemp["proof"] = "";
      createdPayloadTemp["additional_proof"] = "";
      createdPayloadSDK["address"] = createdPayloadTemp;
    }
    if (createdPayloadSDK.containsKey("consent")) {
      if (createdPayloadSDK['consent'].toString() == "{}") {
        createdPayloadSDK['consent'] = {
          "supported_types": ["printed", "handwritten"],
          "text": "",
          "proof": "",
        };
      }
      else {
        createdPayloadTemp = createdPayloadSDK["consent"] as Map<String,Object>;
        if (!createdPayloadTemp.containsKey("supported_types")) {
          String consentText,
              consentAllowOnline,
              consentAllowOffline,
              consentWithFace;
          consentText = createdPayloadSDK["text"].toString();
          consentAllowOffline = createdPayloadSDK["allow_offline"].toString();
          consentAllowOnline = createdPayloadSDK["allow_online"].toString();
          consentWithFace = createdPayloadSDK["with_face"].toString();

          createdPayloadTemp = {
            "supported_types": ["printed", "handwritten"],
            "text": consentText,
            "allow_offline": consentAllowOffline,
            "allow_online": consentAllowOnline,
            "with_face": consentWithFace,
            "proof": "",
          };
          createdPayloadSDK["consent"] = createdPayloadTemp;
        }
      }

      verificationTypeList.add("consent");
      indexTempList.add(createdPayloadSDK.toString().indexOf(' consent:'));
    }

    for (int j = 0; j < verificationTypeList.length - 1; j++) {
      if (indexTempList[j] > indexTempList[j + 1]) {
        // Swapping the elements.
        int temp = indexTempList[j];
        String temp1 = verificationTypeList[j];
        indexTempList[j] = indexTempList[j + 1];
        verificationTypeList[j] = verificationTypeList[j + 1];
        indexTempList[j + 1] = temp;
        verificationTypeList[j + 1] = temp1;
        j = -1;
      }
    }
    return createdPayloadSDK;
  }
}

// stateful widget can change its values
// this is the flow for onsite verification
class Onsite extends StatefulWidget {
  final CalbackFunction callback;

  const Onsite(String this.verification_url,
      {
        // required Key key,
        required this.title,
        required this.callback});
  // : super(key: key);

  final String title;
  final String verification_url;

  @override
  OnsiteVerification createState() => OnsiteVerification(verification_url);
}

class OnsiteVerification extends State<Onsite> {
  String webUrl = "";
  final flutterWebviewPlugin = new FlutterWebviewPlugin();

  OnsiteVerification(String value) {
    webUrl = value;
  }

  @override
  void initState() {
    super.initState();

    // returns an error response if verification url is invalid
    flutterWebviewPlugin.onUrlChanged.listen((String url) {
      if (url.contains("example.com")) {
        widget.callback("event: request.pending, error: '', reference: " +
            createdPayloadSDK["reference"].toString());
        Navigator.pushAndRemoveUntil(
            context,
            MaterialPageRoute(builder: (context) => userHome),
                (route) => false);

        ApiMethods().statusApiRequest().then((response) {
          widget.callback(response);
        });
      }
    });
  }

  // handle the backpress of onsite flow
  Future<bool> _onBackPressed() {
    flutterWebviewPlugin.hide();
    return showDialog(
      context: context,
      barrierDismissible: false,
      builder: (context) => new AlertDialog(
        title: new Text(
          'Confirm Cancellation',
          style: TextStyle(
            fontFamily: 'OpenSans',
          ),
        ),
        content: new Text(
          'Are you sure you want to cancel the verification process?',
          style: TextStyle(
            fontFamily: 'OpenSans',
          ),
        ),
        actions: <Widget>[
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: new GestureDetector(
              onTap: () => {
                flutterWebviewPlugin.show(),
                Navigator.of(context).pop(false)
              },
              child: Text(
                "Not Now",
                style: TextStyle(
                  fontSize: 13.w,
                  color: Color(0xff2b6ad8),
                  fontFamily: 'OpenSans',
                ),
              ),
            ),
          ),
          SizedBox(height: 16),
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: new GestureDetector(
              onTap: () => {
                indexTempList = [],
                verificationTypeList = [],
                isCheck = false,
                Navigator.pushAndRemoveUntil(
                    context,
                    MaterialPageRoute(builder: (context) => userHome),
                        (route) => false),
                flutterWebviewPlugin.dispose(),
                widget.callback(verificatonCancel),
              },
              child: Text(
                "Confirm",
                style: TextStyle(
                  fontSize: 13.w,
                  color: Color(0xff2b6ad8),
                  fontFamily: 'OpenSans',
                ),
              ),
            ),
          ),
        ],
      ),
    ).then((value) => value ?? false);
  }

  // UI of onsite verification
  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: _onBackPressed,
      child: Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          backgroundColor: white,
          elevation: 0.0,
          automaticallyImplyLeading: true,
          leading: GestureDetector(
            onTap: () {
              _onBackPressed();
            },
            child: Container(
              height: 27,
              width: 27,
              alignment: Alignment.centerLeft,
              margin: const EdgeInsets.fromLTRB(20, 0, 0, 0),
              child: Image(
                image: AssetImage("assets/images/back_icon.png"),
                height: 20,
                width: 20,
              ),
            ),
          ),
        ),
        body: Container(
          height: 900.h,
          width: 1.sw,
          alignment: Alignment.center,
          child: new MaterialApp(
            routes: {
              "/": (_) => SafeArea(
                child: Padding(
                  padding: EdgeInsets.only(
                    top: 40.w,
                    left: 0.w,
                    bottom: 0.w,
                    right: 0.w,
                  ),
                  child: new WebviewScaffold(
                    url: webUrl,
                  ),
                ),
              ),
            },
          ),
        ),
      ),
    );
  }
}